"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  default: () => VitePluginGraphQLCodegen
});
module.exports = __toCommonJS(src_exports);
var import_cli = require("@graphql-codegen/cli");

// src/utils/fileMatchers.ts
var import_vite2 = require("vite");

// src/utils/configPaths.ts
var import_vite = require("vite");
var import_plugin_helpers = require("@graphql-codegen/plugin-helpers");
async function getDocumentPaths(context) {
  const config = context.getConfig();
  if (!config.documents)
    return [];
  const normalized = (0, import_plugin_helpers.normalizeInstanceOrArray)(config.documents);
  const documents = await context.loadDocuments(normalized);
  if (!documents.length)
    return [];
  return documents.map(({ location = "" }) => location).filter(Boolean).map(import_vite.normalizePath);
}
async function getSchemaPaths(context) {
  const config = context.getConfig();
  if (!config.schema)
    return [];
  const schemas = (0, import_plugin_helpers.normalizeInstanceOrArray)(config.schema);
  return schemas.filter((schema) => typeof schema === "string").filter(Boolean).map(import_vite.normalizePath);
}

// src/utils/fileMatchers.ts
var isCodegenConfig = async (filePath, context) => {
  if (!context.filepath)
    return false;
  return (0, import_vite2.normalizePath)(filePath) === (0, import_vite2.normalizePath)(context.filepath);
};
var isGraphQLDocument = async (filePath, context) => {
  const documentPaths = await getDocumentPaths(context);
  if (!documentPaths.length)
    return false;
  return documentPaths.some((path) => path === (0, import_vite2.normalizePath)(filePath));
};
var isGraphQLSchema = async (filePath, context) => {
  const schemaPaths = await getSchemaPaths(context);
  if (!schemaPaths.length)
    return false;
  return schemaPaths.some((path) => (0, import_vite2.normalizePath)(filePath).includes(path));
};

// src/utils/viteModes.ts
var modes = {
  serve: "serve",
  build: "build"
};
var { serve, build } = modes;
function isServeMode(mode) {
  return mode === serve;
}
function isBuildMode(mode) {
  return mode === build;
}

// src/utils/debugLog.ts
var RESET = "\x1B[0m";
var BRIGHT = "\x1B[1m";
var DIM = "\x1B[2m";
var FG_CYAN = "\x1B[36m";
function debugLog(...args) {
  const LOG_PREFIX = `${FG_CYAN}${BRIGHT}VITE PLUGIN GRAPHQL CODEGEN${RESET} `;
  console.log(LOG_PREFIX, DIM, ...args, RESET);
}

// src/index.ts
function VitePluginGraphQLCodegen(options) {
  let codegenContext;
  let viteMode;
  const {
    runOnStart = true,
    runOnBuild = true,
    enableWatcher = true,
    throwOnStart = false,
    throwOnBuild = true,
    matchOnDocuments = true,
    matchOnSchemas = false,
    config = null,
    configOverride = {},
    configOverrideOnStart = {},
    configOverrideOnBuild = {},
    configOverrideWatcher = {},
    configFilePathOverride,
    debug = false
  } = options ?? {};
  const log = (...args) => {
    if (!debug)
      return;
    debugLog(...args);
  };
  const generateWithOverride = async (overrideConfig) => {
    const currentConfig = codegenContext.getConfig();
    return (0, import_cli.generate)({
      ...currentConfig,
      ...configOverride,
      ...overrideConfig,
      // Vite handles file watching
      watch: false
    });
  };
  if (options)
    log("Plugin initialized with options:", options);
  return {
    name: "graphql-codegen",
    async config(_config, env) {
      try {
        if (config) {
          log("Manual config passed, creating codegen context");
          codegenContext = new import_cli.CodegenContext({ config });
        } else {
          const cwd = process.cwd();
          log("Loading codegen context:", configFilePathOverride ?? cwd);
          codegenContext = await (0, import_cli.loadContext)(configFilePathOverride);
        }
        log("Loading codegen context successful");
      } catch (error) {
        log("Loading codegen context failed");
        throw error;
      }
      viteMode = env.command;
    },
    async buildStart() {
      if (isServeMode(viteMode)) {
        if (!runOnStart)
          return;
        try {
          await generateWithOverride(configOverrideOnStart);
          log("Generation successful on start");
        } catch (error) {
          log("Generation failed on start");
          if (throwOnStart)
            throw error;
        }
      }
      if (isBuildMode(viteMode)) {
        if (!runOnBuild)
          return;
        try {
          await generateWithOverride(configOverrideOnBuild);
          log("Generation successful on build");
        } catch (error) {
          log("Generation failed on build");
          if (throwOnBuild)
            throw error;
        }
      }
    },
    configureServer(server) {
      if (!enableWatcher)
        return;
      const listener = async (filePath = "") => {
        log("File changed:", filePath);
        const isConfig = await isCodegenConfig(filePath, codegenContext);
        if (isConfig) {
          log("Codegen config file changed, restarting vite");
          server.restart();
          return;
        }
        const matchers = [
          [matchOnDocuments, "document", isGraphQLDocument],
          [matchOnSchemas, "schema", isGraphQLSchema]
        ];
        const matcherResults = await Promise.all(
          matchers.map(async ([enabled, name, matcher]) => {
            if (!enabled) {
              log(`Check for ${name} file skipped in file watcher by config`);
              return false;
            }
            try {
              const isMatch2 = await matcher(filePath, codegenContext);
              log(`Check for ${name} file successful in file watcher`);
              if (isMatch2)
                log(`File matched a graphql ${name}`);
              else
                log(`File did not match a graphql ${name}`);
              return isMatch2;
            } catch (error) {
              log(`Check for ${name} file failed in file watcher`);
              return false;
            }
          })
        );
        const isMatch = matcherResults.some((result) => result);
        if (!isMatch)
          return;
        try {
          await generateWithOverride(configOverrideWatcher);
          log("Generation successful in file watcher");
        } catch (error) {
          log("Generation failed in file watcher");
        }
      };
      server.watcher.on("add", listener);
      server.watcher.on("change", listener);
    }
  };
}
module.exports = module.exports.default;
//# sourceMappingURL=index.js.map